/*
 * Copyright (c) 2007-2015 Freescale Semiconductor, Inc.
 * Copyright 2018-2020 NXP
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 * FreeMASTER Communication Driver - Example Application
 */

////////////////////////////////////////////////////////////////////////////////
// Includes
////////////////////////////////////////////////////////////////////////////////

#include "board.h"
#include "pin_mux.h"
#include "fsl_common.h"
#include "clock_config.h"
#include "fsl_qsci.h"
#include "fsl_cop.h"
#include "fsl_pit.h"
#include "fsl_crc.h"
#include "fsl_sim.h"
#include "fsl_xbara.h"
#include "project_setup_mc56f81768.h"
#include "safety_dsc.h"
#include "iec60730b.h"
#include "safety_test_items.h"

#include "freemaster.h"
#include "freemaster_serial_qsci.h"

#include "freemaster_example.h"

////////////////////////////////////////////////////////////////////////////////
// Local macros define what QSCI port is used
////////////////////////////////////////////////////////////////////////////////

#if 1
	/* Use SCI_1 at Boot_SCI USB-to-serial port */
	#define BOARD_FMSTR_UART_INSTANCE   1
	#define BOARD_FMSTR_UART_CLOCK_NAME kCLOCK_QSCI1
#else
	/* Use SCI_0 at OSJTAG virtual serial port */
	#define BOARD_FMSTR_UART_INSTANCE   0
	#define BOARD_FMSTR_UART_CLOCK_NAME kCLOCK_QSCI0
#endif

#define BOARD_FMSTR_UART_BASE_ADDR  qsciBases[BOARD_FMSTR_UART_INSTANCE]

/* Macro to access the QSCI IRQn interrupt vector number */
#define QSCIx_IRQn(x, irq)  QSCI##x##_##irq##_IRQn
#define QSCIx_RERR_IRQn(x)  QSCIx_IRQn(x, RERR)
#define QSCIx_RCV_IRQn(x)   QSCIx_IRQn(x, RCV)
#define QSCIx_TDRE_IRQn(x)  QSCIx_IRQn(x, TDRE)
#define QSCIx_TRIDLE_IRQn(x) QSCIx_IRQn(x, TRIDLE)

/* Macro to declare IRQ handler for QSCI module number defined by a macro.
 * Refer to vector table and associated IRQ handlers. */
#define QSCI_IRQ_HANDER2(x, vec) ivINT_QSCI##x##_##vec
#define QSCI_IRQ_HANDER(x, vec) QSCI_IRQ_HANDER2(x, vec) /* two-phase to enable x macro to expand */

////////////////////////////////////////////////////////////////////////////////
// Variables
////////////////////////////////////////////////////////////////////////////////

// array of all QSCI base addresses
const QSCI_Type *qsciBases[] = QSCI_BASE_PTRS;

//! Note: All global variables accessed by FreeMASTER are defined in a shared
//! freemaster_example.c file

////////////////////////////////////////////////////////////////////////////////
// Prototypes
////////////////////////////////////////////////////////////////////////////////

static void init_freemaster_qsci(void);

#define PIT_IRQ_PRIO 1 /* Priority level 0*/
volatile uint16_t exception_counter;
volatile uint16_t refresh_on;
volatile uint16_t ui16reset_source;
volatile bool pitIsrFlag = false;
ram_test_t g_sSafetyRamTest; 
#pragma define_section safety_ram ".safety_ram.data" RW
#pragma section safety_ram begin
cop_test_t g_sSafetyCopTest;
crc_config_t sCrcConfig;
safety_common_t g_sSafetyCommon;
fs_clock_test_t g_sSafetyClockTest;
#pragma section safety_ram end
extern uint16_t _pc_test_flag;   /* from Linker configuration file */
extern uint32_t _safety_ram;     /* start of section for ram test ,from Linker command file */
extern uint32_t _end_safety_ram; /* end of section for ram test, from Linker command file */
extern __pmem CRC16_record g_crc_linker;
extern uint32_t start_text;
extern uint32_t end_text;
flash_runtime_test_parameters_t g_sFlashCrc;
flash_configuration_parameters_t g_sFlashConfig;
////////////////////////////////////////////////////////////////////////////////
// Code
////////////////////////////////////////////////////////////////////////////////

FMSTR_TSA_TABLE_BEGIN(main_table)
FMSTR_TSA_RW_VAR(refresh_on, FMSTR_TSA_UINT16)
FMSTR_TSA_RW_VAR(ui16reset_source, FMSTR_TSA_UINT16)
FMSTR_TSA_RW_VAR(exception_counter, FMSTR_TSA_UINT16)
FMSTR_TSA_RW_VAR(g_sSafetyCommon, FMSTR_TSA_USERTYPE(safety_common_t))
FMSTR_TSA_RW_VAR(g_sSafetyClockTest, FMSTR_TSA_USERTYPE(fs_clock_test_t))
FMSTR_TSA_RW_VAR(g_sSafetyCopTest, FMSTR_TSA_USERTYPE(cop_test_t))
FMSTR_TSA_RW_VAR(g_sFlashCrc, FMSTR_TSA_USERTYPE(flash_runtime_test_parameters_t))
FMSTR_TSA_RW_VAR(g_sFlashConfig, FMSTR_TSA_USERTYPE(flash_configuration_parameters_t))
FMSTR_TSA_TABLE_END()


int main(void)
{
	uint16_t clock_test_condition = 0;   
	uint16_t delay;
	uint8_t i; 
	refresh_on = 1;
    /* Board initialization */
    BOARD_InitPins();
    BOARD_BootClockRUN();
    
    LED_GREEN_INIT(kGPIO_OutputLow);

#ifdef WATCHDOG_ENABLED
    watchdogEnable(COP_TIMEOUT_IN_MICRO_SECONDS);
#endif 
    ui16reset_source = SafetyWatchdogTest(&g_sSafetyCopTest);
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    /*****************/
    /* CPU test      */
    /*****************/ 
    SafetyCpuAfterResetTest(&g_sSafetyCommon);   
    watchdogRefresh(); //**********COP*****WATCHDOG***********
	/*****************/
    /* Stack test    */
	/*****************/
    SafetyStackTestInit();
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SafetyStackTest(&g_sSafetyCommon);
    /*****************/
    /* Flash test    */
    /*****************/ 
#if(HW_FLASH_TEST)    
//    CRC_GetDefaultConfig(&sCrcConfig, kCRC_Crc16);
//   CRC_Init(CRC, &sCrcConfig);
    CLOCK_EnableClock(kCLOCK_CRC);    
#endif
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SafetyFlashTestInit(&g_sFlashCrc, &g_sFlashConfig, &g_crc_linker);
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SafetyFlashAfterResetTest(&g_sSafetyCommon, &g_sFlashConfig);
    watchdogRefresh(); //**********COP*****WATCHDOG***********
#if PC_TEST_ENABLED
	/* Program Counter test */
    g_sSafetyCommon.PC_test_result =  FS_PC_Test(FS_PC_object_1, FS_PC_subroutine, (unsigned short *)&_pc_test_flag); //TODO: set address of object
    g_sSafetyCommon.PC_test_result |= FS_PC_Test(FS_PC_object_2, FS_PC_subroutine, (unsigned short *)&_pc_test_flag);
    watchdogRefresh(); //**********COP*****WATCHDOG***********
#endif
#if RAM_TEST_ENABLED
    /* Ram test init for Safety related RAM space */
    SafetyRamTestInit(&g_sSafetyRamTest, &_safety_ram, &_end_safety_ram);
    /* Ram after-reset test for safety related memory*/
    SafetyRamAfterResetTest(&g_sSafetyCommon, &g_sSafetyRamTest);  
    watchdogRefresh(); //**********COP*****WATCHDOG***********
#endif
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    /*****************/
    /* DIO test      */
    /*****************/
    for (i=0; dio_safety_test_items[i]!= 0; i++)
    {
		SafetyDigitalOutputTest(&g_sSafetyCommon,dio_safety_test_items[i]);
		SafetyDigitalInputOutput_ShortSupplyTest(&g_sSafetyCommon,dio_safety_test_items[i], DIO_SHORT_TO_GND_TEST);
		SafetyDigitalInputOutput_ShortSupplyTest(&g_sSafetyCommon,dio_safety_test_items[i], DIO_SHORT_TO_VDD_TEST);
    }
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SafetyDigitalInputOutput_ShortAdjTest(&g_sSafetyCommon, dio_safety_test_items[0],dio_safety_test_items[1], LOGICAL_ONE); 
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SafetyDigitalInputOutput_ShortAdjTest(&g_sSafetyCommon, dio_safety_test_items[0],dio_safety_test_items[1], LOGICAL_ZERO); 
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    /*****************/
    /* ADC test      */
    /*****************/  
    /* ADC init */
    /* GPIO A4 set as ANA4,  GPIO A5 set as ANA5 inputs */
    ADC_Init();    
    watchdogRefresh(); //**********COP*****WATCHDOG***********   
    SafetyAnalogTestInitialization(); /* initialisation of ADC test */     
    for (i=0;i<6;i++)
    {
        watchdogRefresh(); //**********COP*****WATCHDOG***********	
        SafetyAnalogTest(&g_sSafetyCommon);
        for(delay=0;delay<1000;delay++)
        {
        	asm(NOP);
        }
    }
    __EI0();
    CLOCK_EnableClock(BOARD_FMSTR_UART_CLOCK_NAME);

    watchdogRefresh(); //**********COP*****WATCHDOG***********
    /* FreeMASTER communication layer initialization */
    init_freemaster_qsci();

    watchdogRefresh(); //**********COP*****WATCHDOG***********
    /* This example uses shared code from FreeMASTER generic example application */
    FMSTR_Example_Init();
    watchdogRefresh(); //**********COP*****WATCHDOG***********

#if CLOCK_TEST_ENABLED   
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    XBARA_Init(XBARA); 
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    XBARA_SetSignalsConnection(XBARA,kXBARA_InputPit1SyncOut,kXBARA_OutputTa0In);   
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    SIM_SetInternalPeriInput(SIM, kSIM_TMRA0InputIndex, kSIM_TMRA0Input_XB_OUT38); 
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    TMRA0_initialization();
    watchdogRefresh(); //**********COP*****WATCHDOG***********
    PIT1_initialization(3052U, kPIT_PrescalerDivBy512);
    watchdogRefresh(); //**********COP*****WATCHDOG***********  
    SafetyClockTestInit(&g_sSafetyCommon, &g_sSafetyClockTest);
#endif   /*CLOCK_TEST_ENABLED */
    PIT0_initialization(PIT0_RELOAD,PIT0_CLOCK_DIV);
    EnableIRQWithPriority(PIT0_ROLLOVR_IRQn, PIT_IRQ_PRIO);      
    while(1)
    {
        /*****************/
        /* Clock test    */
        /*****************/ 
    	if (exception_counter >10)
    		clock_test_condition |=1;
    	if(clock_test_condition)
    	{
    	g_sSafetyCommon.CLOCK_test_result = FS_CLK_QTIMER_Check(&g_sSafetyClockTest);
 //   	QTMR_ClearStatusFlags(TMRA, kQTMR_Channel0, TMR_SCTRL_IEF_MASK);
    	}
    	SafetyFlashRuntimeTest(&g_sSafetyCommon, &g_sFlashCrc, &g_sFlashConfig);
    	SafetyAnalogTest(&g_sSafetyCommon);
    	SafetyStackTest(&g_sSafetyCommon);
        FMSTR_Example_Poll();
    }
}
#pragma interrupt saveall
void ivINT_PIT0_ROLLOVR(void);
void ivINT_PIT0_ROLLOVR(void)
{
	GPIO_PinWrite(GPIOC, kGPIO_Pin6, kGPIO_OutputHigh);
    /* Clear interrupt flag.*/
    PIT_ClearStatusFlags(PIT0);
    exception_counter ++;
    if(exception_counter ==20)
    {
    	LED_GREEN_TOGGLE();
    	exception_counter = 0;  	
    }
    SafetyRamRuntimeTest(&g_sSafetyCommon, &g_sSafetyRamTest);
    if(refresh_on)
    {
        watchdogRefresh(); //**********COP*****WATCHDOG***********
    }   
}
#pragma interrupt off

/*!
 * @brief QSCI Module initialization
 */
static void init_freemaster_qsci(void)
{
	qsci_config_t config;
	uint32_t uartClkSrcFreq;

    uartClkSrcFreq = CLOCK_GetIpClkSrcFreq(BOARD_FMSTR_UART_CLOCK_NAME);
    /*
     * config.baudRate_Bps = 115200U;
     * config.parityMode = kUART_ParityDisabled;
     * config.stopBitCount = kUART_OneStopBit;
     * config.txFifoWatermark = 0;
     * config.rxFifoWatermark = 1;
     * config.enableTx = false;
     * config.enableRx = false;
     */
    QSCI_GetDefaultConfig(&config, 115200U, uartClkSrcFreq);
    config.bEnableTx = false;
    config.bEnableRx = false;

    QSCI_Init((QSCI_Type*)BOARD_FMSTR_UART_BASE_ADDR, &config);

    /* Register communication module used by FreeMASTER driver. */
    FMSTR_SerialSetBaseAddress((QSCI_Type*)BOARD_FMSTR_UART_BASE_ADDR);

#if FMSTR_SHORT_INTR || FMSTR_LONG_INTR
    /* Enable UART interrupts. */
    EnableIRQWithPriority(QSCIx_RERR_IRQn(BOARD_FMSTR_UART_INSTANCE), 1);
    EnableIRQWithPriority(QSCIx_RCV_IRQn(BOARD_FMSTR_UART_INSTANCE), 1);
    EnableIRQWithPriority(QSCIx_TDRE_IRQn(BOARD_FMSTR_UART_INSTANCE), 1);
    EnableIRQWithPriority(QSCIx_TRIDLE_IRQn(BOARD_FMSTR_UART_INSTANCE), 1);
    SetIRQBasePriority(0);
    EnableGlobalIRQ(1);
#endif
}

#if FMSTR_SHORT_INTR || FMSTR_LONG_INTR

/* Prototypes of interrupt handlers */
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, RERR)(void);
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, RCV)(void);
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, TRIDLE)(void);
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, TDRE)(void);

/* All interrupt handlers call FreeMASTER Interrupt routine handler */
#pragma interrupt alignsp saveall
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, RERR)(void)
{
    FMSTR_SerialIsr();
}
#pragma interrupt off

#pragma interrupt alignsp saveall
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, RCV)(void)
{
    FMSTR_SerialIsr();
}
#pragma interrupt off

#pragma interrupt alignsp saveall
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, TRIDLE)(void)
{
    FMSTR_SerialIsr();
}
#pragma interrupt off

#pragma interrupt alignsp saveall
void QSCI_IRQ_HANDER(BOARD_FMSTR_UART_INSTANCE, TDRE)(void)
{
    FMSTR_SerialIsr();
}
#pragma interrupt off
#endif
