/*
* Copyright (c) 2016, Freescale Semiconductor, Inc.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* o Redistributions of source code must retain the above copyright notice, this list
*   of conditions and the following disclaimer.
*
* o Redistributions in binary form must reproduce the above copyright notice, this
*   list of conditions and the following disclaimer in the documentation and/or
*   other materials provided with the distribution.
*
* o Neither the name of Freescale Semiconductor, Inc. nor the names of its
*   contributors may be used to endorse or promote products derived from this
*   software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
* ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "safety_config.h"
#include "project_setup_mc56f81768.h"
#include "clock_config.h"
#include "pin_mux.h"
#include "fsl_pit.h"
#include "fsl_qtmr.h"
#include "fsl_cop.h"
#include "fsl_cadc.h"
#include "fsl_pmc.h"
//#include "fsl_clock.h"

cop_config_t sCopConfig;

pit_config_t sPit0config;
pit_config_t sPit1Config;

qtmr_config_t sTMRA0Config = {0};
qtmr_channel_config_t sChannel0Config;

cadc_config_t sCADC_Config;
cadc_converter_config_t sCAD_ConverterAConfig;
cadc_converter_config_t sCAD_ConverterBConfig;
/*******************************************************************************
* Code
******************************************************************************/

/*!
* @brief  Sets port direction and mux
*
* @param 
*
* @return  None
*/
void PortInit(GPIO_Type *pGpio, uint16_t pinDir, uint16_t pinNum, uint16_t pull)
{
	pGpio->PER &=  ~(1<< pinNum); // Force GPIO mode 
	pGpio->PUR |= (1<< pinNum); // Enable Pull resistor (efective only in IN mode 
	pGpio->PUS  &= ~(1<< pinNum);  /* set pull-down  */
	    
	if(pull) { 
	  pGpio->PUS |= (1<< pinNum);  /* if PULL, set pull-up, otherwise remain pull-down  */
	    }
	
    if (pinDir == PIN_DIRECTION_OUT)
    {
    	pGpio->DDR |= (1<< pinNum); // set bit in DDR - OUTPUT 
    }
    else if (pinDir == PIN_DIRECTION_IN)
    {
    	pGpio->DDR &= ~(1<< pinNum); // Clear DDR - INPUT
    }
}

void PIT0_initialization(uint32_t pit_timeout, pit_prescaler_value_t divide_by)
{
	CLOCK_EnableClock(kCLOCK_PIT0);
    sPit0config.bEnableSlaveMode = 0;
    sPit0config.ePrescaler = divide_by; //kPIT_PrescalerDivBy128;
    sPit0config.bEnableTimer = 1;
    sPit0config.eClockSource = kPIT_CountFircClk; 
    sPit0config.bEnableInterrupt = true;
    sPit0config.u32PeriodCount = pit_timeout; //3052U;  
    
    PIT_SetTimerPeriod(PIT0, sPit0config.u32PeriodCount);	
    PIT_Init(PIT0, &sPit0config);    	
}


void PIT1_initialization(uint32_t pit_timeout, pit_prescaler_value_t divide_by)
{
	CLOCK_EnableClock(kCLOCK_PIT1);
    PIT_GetDefaultConfig(&sPit1Config);
    sPit1Config.eClockSource = kPIT_CountFircClk; 
    sPit1Config.ePrescaler   = divide_by; //kPIT_PrescalerDivBy512;
    sPit1Config.u32PeriodCount = pit_timeout; //3052U;
    sPit1Config.bEnableInterrupt = false;
    sPit1Config.bEnableTimer     = true;

    /* Initialize pit module */
    PIT_Init(PIT1, &sPit1Config);
}


void TMRA0_initialization(void)
{
	CLOCK_EnableClock(kCLOCK_TA0);

    sTMRA0Config.psChannelConfig[kQTMR_Channel0] = &sChannel0Config;
    
    sChannel0Config.sInputConfig.ePrimarySource = kQTMR_PrimarySrcIPBusClockDivide64;
    sChannel0Config.sInputConfig.eSecondarySource = kQTMR_SecondarySrcInputPin0;
    sChannel0Config.sInputConfig.eSecondarySourceCaptureMode = kQTMR_SecondarySrcCaptureRisingEdgeWithReload;
    sChannel0Config.sCountConfig.eCountMode = kQTMR_CountPrimarySrcRiseEdge;
       
    QTMR_SetDebugActions(TMRA,kQTMR_Channel0, kQTMR_DebugRunNormal);
    QTMR_Init(TMRA, &sTMRA0Config);
    QTMR_EnableChannels(TMRA, (uint16_t)(1UL << (uint16_t)kQTMR_Channel0));
}

void ADC_Init(void)
{
	uint16_t disamble_samples;
	CLOCK_EnableClock(kCLOCK_CYCADC);
	/* enable bandgap reference */
    PMC_EnableVoltageReferenceBuffer(PMC, true);

     // TODO  functions works in oposite !!!
//    CADC_SetChannelMode(ADC, kCADC_ANA0_1_SingleEnd);
//    CADC_SetChannelMode(ADC, kCADC_ANA2_3_SingleEnd);
//    CADC_SetChannelMode(ADC, kCADC_ANB0_1_SingleEnd);
//    CADC_SetChannelMode(ADC, kCADC_ANB2_3_SingleEnd);
//    CADC_SetChannelMode(ADC, kCADC_ANA4_5_SingleEnd);
//    CADC_SetChannelMode(ADC, kCADC_ANA6_7_SingleEnd);
//    sCADC_Config.uDisabledSampleSlot.eSequentialModeDisSample = kCADC_Sample0Disabled;
//    sCADC_Config.uDisabledSampleSlot.eSequentialModeDisSample = kCADC_Sample1Disabled;
//    CADC_Init(ADC, &sCADC_Config);
    disamble_samples = 0xFFFF;
    disamble_samples &= ~(kCADC_Sample0Disabled | kCADC_Sample1Disabled);
    
    ADC->SDIS = disamble_samples;
    
    CADC_SetScanMode(ADC, kCADC_ScanModeTriggeredParallelIndependent);
    CADC_EnableConverter(ADC, kCADC_ConverterA, true); // enable stop mode
//    CADC_SetConverterClockDivisor(ADC, kCADC_ConverterA, (uint16_t)5);
    CADC_SetPowerUpDelay(ADC, (uint16_t)0x20);
    
    sCAD_ConverterAConfig.bEnableDMA = false;
    sCAD_ConverterAConfig.bPowerUp = true;
    sCAD_ConverterAConfig.bScanInitBySync = false;
    sCAD_ConverterAConfig.u16ClockDivisor = 5;
    CADC_SetConverterConfig(ADC, kCADC_ConverterA, &sCAD_ConverterAConfig);
    
    sCAD_ConverterBConfig.bEnableDMA = false;
    sCAD_ConverterBConfig.bPowerUp = true;
    sCAD_ConverterBConfig.bScanInitBySync = false;
    sCAD_ConverterBConfig.u16ClockDivisor = 4;
    CADC_SetConverterConfig(ADC, kCADC_ConverterB, &sCAD_ConverterBConfig);
    CADC_EnableConverter(ADC, kCADC_ConverterB, false);

    CADC_RouteChannelToSampleSlot(ADC, kCADC_SampleSlot0Index, kCADC_SingleEndANA4_DiffANA4pANA5n);
    CADC_RouteChannelToSampleSlot(ADC, kCADC_SampleSlot1Index, kCADC_SingleEndANA5_DiffANA4pANA5n);
    CADC_RouteChannelToSampleSlot(ADC, kCADC_SampleSlot2Index, kCADC_SingleEndANA5_DiffANA4pANA5n);
    CADC_RouteChannelToSampleSlot(ADC, kCADC_SampleSlot3Index, kCADC_SingleEndANA3_DiffANA2pANA3n);
    CADC_EnableConverterPower(ADC, kCADC_ConverterA, true);
    
}
		
void watchdogEnable(unsigned long timeout_in_us)
{	
	COP_GetDefaultConfig(&sCopConfig);
	
	sCopConfig.bEnableCOP = true;
	sCopConfig.bEnableInterrupt = false;
	sCopConfig.bEnableWriteProtect = false;
	sCopConfig.eClockSource = kCOP_LpoClockSource;
	sCopConfig.ePrescaler = kCOP_ClockPrescalerDivide1;	
	sCopConfig.u16TimeoutCount = (timeout_in_us / (uint32_t)5);   // valid only with kCOP_LpoClockSource and kCOP_ClockPrescalerDivide1
	COP_Init(COP, &sCopConfig);
		
	
}

void watchdogRefresh(void)
{
#ifdef WATCHDOG_ENABLED    
    COP_Refresh(COP);
#endif  
}




/*!
 * @brief   Setup of Clock
 *
 * @return  None
 */
void ClockInit(void)
{
    /* SDK Initialization */
    BOARD_BootClockRUN();
}


void PinsInit(void)
{
    /* SDK Initialization */
	BOARD_InitPins();
}


