/*******************************************************************************
*
* Copyright 2004-2016, Freescale Semiconductor, Inc.
* Copyright 2016-2019 NXP
* All rights reserved.
*
********************************************************************************
*
* File Name:  scihl.h
*
* Description: Header file for the SCI driver - calculation of HIGHLEVEL mode
*
*******************************************************************************/

#ifndef __SCIHL_H
#define __SCIHL_H

#ifndef __APPCONFIG_H
#error appconfig.h must be included before scihl.h
#endif

#ifndef __SCI_H
#error sci.h must be included before scihl.h
#endif

/* if not yet defined, test which high level mode will be used for SCI modules */
/* i.e. select the mode suitable for both SCI_0 and SCI_1 */

#ifndef SCI_HIGHLEVEL_MODE
#if SCI_0_HIGHLEVEL_MODE
/* same as SCI_0 */
#define SCI_HIGHLEVEL_MODE SCI_0_HIGHLEVEL_MODE
#if SCI_1_HIGHLEVEL_MODE && (SCI_1_HIGHLEVEL_MODE != SCI_0_HIGHLEVEL_MODE)
/* different non-zero modes for SCI_0 and SCI_1 */
#error Different high level modes selected for SCI_0 and SCI_1.
#endif
#elif SCI_1_HIGHLEVEL_MODE
/* same as SCI_1 */
#define SCI_HIGHLEVEL_MODE SCI_1_HIGHLEVEL_MODE
#else
/* no high-level function by default */
#define SCI_HIGHLEVEL_MODE SCI_HIGHLEVEL_MODE_NONE    
#endif
#endif

#if (SCI_1_HIGHLEVEL_MODE == SCI_HIGHLEVEL_MODE_BUFFERED)
   
    #if (SCI_1_RX_BUFFER_SIZE == 0)
    /* SCI_1 RX buffer can't be set to 0 in buffered mode */
    #error SCI 1 RX buffer is set to 0.
    #endif

    #if (SCI_1_TX_BUFFER_SIZE == 0)
    /* SCI_1 TX buffer can't be set to 0 in buffered mode */
    #error SCI 1 TX buffer is set to 0.
    #endif

#endif

#if (SCI_0_HIGHLEVEL_MODE == SCI_HIGHLEVEL_MODE_BUFFERED)
   
    #if (SCI_0_RX_BUFFER_SIZE == 0)
    /* SCI_0 RX buffer can't be set to 0 in buffered mode */
    #error SCI 0 RX buffer is set to 0.
    #endif

    #if (SCI_0_TX_BUFFER_SIZE == 0)
    /* SCI_0 TX buffer can't be set to 0 in buffered mode */
    #error SCI 0 TX buffer is set to 0.
    #endif

#endif


#endif /* __SCIHL_H */




