/*
 * Copyright 2015 Freescale Semiconductor, Inc.
 * Copyright 2015-2021 NXP.
 *
 * License: LA_OPT_NXP_Software_License
 *
 * This software is owned or controlled by NXP and may
 * only be used strictly in accordance with the applicable license terms.
 * By expressly accepting such terms or by downloading, installing,
 * activating and/or otherwise using the software, you are agreeing that
 * you have read, and that you agree to comply with and are bound by,
 * such license terms.  If you do not agree to be bound by the applicable
 * license terms, then you may not retain, install, activate or otherwise
 * use the software.
 * 
 * @version   4.1
 * 
 * @brief     IEC60730 Class B Safety Routines for Clock test dedicated for MC65F83xxx, MC56F81xxx
 *
 */

#ifndef _IEC60730B_CLOCK_
#define _IEC60730B_CLOCK_

/******************************************************************************
 * Macros
 ******************************************************************************/
/* Clock test result constants */
#define FS_CLK_PASS      (0x00000000)
#define FS_CLK_FAIL      (FS_CLK_FAIL_CODE|0x1)
#define FS_CLK_PROGRESS  (FS_CLK_FAIL_CODE|0x2)


#ifndef __ASM__

/******************************************************************************
 * Definitions
 ******************************************************************************/
/*one channel of QTIMER - Peripheral register structure */
typedef struct
{
	uint16_t TMR_COMP1;
	uint16_t TMR_COMP2;
	uint16_t TMR_CAPT;
	uint16_t TMR_LOAD;
	uint16_t TMR_HOLD;
	uint16_t TMR_CNTR;
	uint16_t TMR_CTRL;
	uint16_t TMR_SCTRL;
	uint16_t TMR_CMPLD1;
	uint16_t TMR_CMPLD2;
	uint16_t TMR_CSCTRL;
	uint16_t TMR_FILT;
	uint16_t TMR_DMA;
	
} FS_CHAN_QTIMER_Type;

/* Safety Clock test */
typedef struct _clock_test
{
  FS_CHAN_QTIMER_Type * qtimer_channel_base;
  uint16_t clockTestContext;
  uint16_t clockTestTolerance;
  uint16_t clockTestExpected;
  uint16_t clockTestLimitHigh;
  uint16_t clockTestLimitLow;
} fs_clock_test_t;


/******************************************************************************
* Functions
******************************************************************************/   
/*******************************************************************************
*
* @brief  Function read capture register from QTIMER and checks if the value is within the defined limits. 
*
* @param  pClockTest - pointer to an instance of Clock test
*
* @return FS_RESULT: - FS_CLK_PROGRESS
*                    - FS_CLK_FAIL
*                    - FS_CLK_PASS
*
*******************************************************************************/
FS_RESULT FS_CLK_QTIMER_Check(fs_clock_test_t *pClockTest);


#endif /* __ASM__ */

#endif /* _IEC60730B_CLOCK_ */
