/*
 * Copyright 2015 Freescale Semiconductor, Inc.
 * Copyright 2015-2021 NXP.
 *
 * License: LA_OPT_NXP_Software_License
 *
 * This software is owned or controlled by NXP and may
 * only be used strictly in accordance with the applicable license terms.
 * By expressly accepting such terms or by downloading, installing,
 * activating and/or otherwise using the software, you are agreeing that
 * you have read, and that you agree to comply with and are bound by,
 * such license terms.  If you do not agree to be bound by the applicable
 * license terms, then you may not retain, install, activate or otherwise
 * use the software.
 * 
 * @version   4.1
 * 
 * @brief     IEC60730 Class B Safety Routines for the watchdog test dedicated for MC65F83xxx, MC56F81xxx
 *
 */

#ifndef _IEC60730B_DSC_WDG_
#define _IEC60730B_DSC_WDG_


#ifndef __ASM__

/******************************************************************************
* Definitions
******************************************************************************/
/* Structure of WD_test variables */
/* must be placed in memory which is not touched by startup code,  which is only chagned by POR reset */
//typedef struct {
//  unsigned long counter;
//  unsigned long resets;
//  unsigned long wd_test_uncomplete_flag;
//}volatile fs_wdog_test;
  
typedef struct {
  unsigned long counter;
  unsigned short resets;
  unsigned short wd_test_uncomplete_flag;
}volatile fs_wdog_test;
/******************************************************************************
* Functions
******************************************************************************/
/*********************************************************************************************************
* @brief  This function should be called only once after POR reset. - each calling of this function causes a COP reset
*         Function clears the COP resets counter to 0. No COP settings are changed here.
*         Within the waiting endless loop, value from PIT is periodically stored to reserved area in RAM
*            
* @param   pWatchdogBackup - pointer to structure with WD_test variables
*          pit_base        - base address of PIT timer
*          counter_32_bit  - enter 0 if the device has 16-bit PIT counter, enter 1 or non-zero value, if the device has 32-bit PIT counter
*          
* @return  void
**********************************************************************************************************/
//void FS_watchdog_setup_draft(fs_wdog_test* pWatchdogBackup, unsigned short pit_base, unsigned char counter_32_bit);
void FS_watchdog_setup(fs_wdog_test* pWatchdogBackup, unsigned short pit_base, unsigned char counter_32_bit);

/*********************************************************************************************************
* @brief  function should be called after every COP-timeout reset, its calling should be handled by conditional execution in application
*         if the source of reset is COP function increments the wd_reset counter
*         if the reset counter has overflowed, function will wait in endless loop if it is enabled
*         if the source of reset is COP, function next check the timeout value, if it is not in range, function will wait in endless loop if it is enabled
*         if the source of reset isn't COP or POR, function will sets the wd_test_uncomplete_flag and will wait in endless loop if it is enabled
*         
* @param   limit_high           - precalculated high limit value for PIT counter
*          limit_low            - precalculated low limit value for PIT counter
*          resets_limit         - limit value for COP resets
*          endless_loop_enable  - enable, or disable endless loop within the function
*          pWatchdogBackup      - pointer to structure with WD_test variables
*          
* @return   void
**********************************************************************************************************/
void FS_watchdog_check(unsigned long limit_high, unsigned long limit_low, unsigned short resets_limit, unsigned short endless_loop_enable, fs_wdog_test* pWatchdogBackup);


#endif /* __ASM__ */

#endif /* _IEC60730B_DSC_WDG_ */
